firewall {
    all-ping enable
    broadcast-ping disable
    ipv6-receive-redirects disable
    ipv6-src-route disable
    ip-src-route disable
    log-martians enable
    name WAN_IN {
        default-action drop
        description "WAN to internal"
        rule 10 {
            action accept
            description "Allow established/related"
            state {
                established enable
                related enable
            }
        }
        rule 20 {
            action drop
            description "Drop invalid state"
            state {
                invalid enable
            }
        }
    }
    name WAN_LOCAL {
        default-action drop
        description "WAN to router"
        rule 10 {
            action accept
            description "Allow established/related"
            state {
                established enable
                related enable
            }
        }
        rule 20 {
            action drop
            description "Drop invalid state"
            state {
                invalid enable
            }
        }
    }
    receive-redirects disable
    send-redirects enable
    source-validation disable
    syn-cookies enable
}
interfaces {
    ethernet eth0 {
        address dhcp
        description Internet
        duplex auto
        firewall {
            in {
                name WAN_IN
            }
            local {
                name WAN_LOCAL
            }
        }
        speed auto
        traffic-policy {
        }
    }
    ethernet eth1 {
        address 192.168.0.1/24
        description Local
        duplex auto
        speed auto
        traffic-policy {
        }
    }
    ethernet eth2 {
        address 192.168.1.1/24
        description "Local 2"
        duplex auto
        speed auto
    }
    loopback lo {
    }
}
port-forward {
    auto-firewall enable
    hairpin-nat enable
    lan-interface eth1
    rule 1 {
        description uTorrent
        forward-to {
            address 192.168.0.101
            port 54784
        }
        original-port 54784
        protocol tcp_udp
    }
    wan-interface eth0
}
service {
    dhcp-server {
        disabled false
        hostfile-update disable
        shared-network-name LAN1 {
            authoritative enable
            subnet 192.168.0.0/24 {
                default-router 192.168.0.1
                dns-server 192.168.0.1
                lease 86400
                start 192.168.0.38 {
                    stop 192.168.0.243
                }
                static-mapping C530-IP {
                    ip-address 192.168.0.102
                    mac-address 7c:2f:80:bf:40:7e
                }
                static-mapping DUNE {
                    ip-address 192.168.0.104
                    mac-address 14:c0:89:14:2a:95
                }
                static-mapping OpenELEC {
                    ip-address 192.168.0.103
                    mac-address b8:27:eb:82:af:e7
                }
                static-mapping SRV-AMIDALA {
                    ip-address 192.168.0.101
                    mac-address ac:22:0b:4f:3d:42
                }
                static-mapping Yoda {
                    ip-address 192.168.0.100
                    mac-address 00:25:22:dc:3b:fd
                }
            }
        }
        shared-network-name LAN2 {
            authoritative enable
            subnet 192.168.1.0/24 {
                default-router 192.168.1.1
                dns-server 192.168.1.1
                lease 86400
                start 192.168.1.38 {
                    stop 192.168.1.243
                }
            }
        }
        use-dnsmasq disable
    }
    dns {
        forwarding {
            cache-size 150
            listen-on eth1
            listen-on eth2
        }
    }
    gui {
        http-port 80
        https-port 443
        older-ciphers enable
    }
    nat {
        rule 5010 {
            description "masquerade for WAN"
            outbound-interface eth0
            type masquerade
        }
    }
    ssh {
        port 22
        protocol-version v2
    }
}
system {
    host-name ubnt
    login {
        user sgilbert {
            authentication {
                encrypted-password $6$LI5GobQe8.mjG15$qcBJcD4s4hDWdNN.Rn/1f5z1GIPaHcJ4MCtjkfVt2/ThVJv0mZScYHMRqdUDZoVE3Wjer0jKP2KjciukBrVC01
                plaintext-password ""
            }
            full-name "Sylvain GILBERT"
            level admin
        }
    }
    ntp {
        server 0.ubnt.pool.ntp.org {
        }
        server 1.ubnt.pool.ntp.org {
        }
        server 2.ubnt.pool.ntp.org {
        }
        server 3.ubnt.pool.ntp.org {
        }
    }
    syslog {
        global {
            facility all {
                level notice
            }
            facility protocols {
                level debug
            }
        }
    }
    time-zone Europe/Paris
    traffic-analysis {
        dpi enable
        export enable
    }
}
traffic-control {
    advanced-queue {
        branch {
        }
        filters {
        }
        leaf {
        }
        queue-type {
        }
        root {
        }
    }
}
traffic-policy {
}


/* Warning: Do not remove the following line. */
/* === vyatta-config-version: "config-management@1:conntrack@1:cron@1:dhcp-relay@1:dhcp-server@4:firewall@5:ipsec@5:nat@3:qos@1:quagga@2:system@4:ubnt-pptp@1:ubnt-unms@1:ubnt-util@1:vrrp@1:webgui@1:webproxy@1:zone-policy@1" === */
/* Release version: v1.9.7+hotfix.1.5005851.170803.0322 */

